LimeTr Wrapper for Forecast Team
================================

.. image:: https://travis-ci.com/ihmeuw-msca/lme-for-forecast.svg?branch=master
    :target: https://travis-ci.com/ihmeuw-msca/lme-for-forecast